pub fn load_from_file<T: DeserializeOwned>(
path: &Path,
) -> Result<T, SynapticError>Expand description
Load and parse configuration from a file path (convenience wrapper).
pub fn load_from_file<T: DeserializeOwned>(
path: &Path,
) -> Result<T, SynapticError>Load and parse configuration from a file path (convenience wrapper).